@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2019
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_TOPAZ_CONNECTED_SUM_H
-#define POLYMAKE_TOPAZ_CONNECTED_SUM_H
+#pragma once
 
 #include "polymake/Array.h"
 #include "polymake/Set.h"
@@ -26,8 +25,6 @@
 
 namespace polymake { namespace topaz {
 
-typedef hash_map<int,int> map;
-
 /// Computes the connected sum of two complexes and adjusts the labels.
 /// The client writes the new lables into L1.
 /// If the labels are empty, the client just ignores them.
@@ -35,31 +32,29 @@ typedef hash_map<int,int> map;
 /// vertices of f2 get glued.
 /// If the map is empty, the trivial map is used.
 template <typename Complex_1, typename Complex_2>
-std::list< Set<int> > connected_sum(const Complex_1& C1,
-                                    const Complex_2& C2,
-                                    const int f1, const int f2,
-                                    Array<std::string>& L1,
-                                    const Array<std::string>& L2,
-                                    map& P);
+std::list<Set<Int>> connected_sum(const Complex_1& C1,
+                                  const Complex_2& C2,
+                                  const Int f1, const Int f2,
+                                  Array<std::string>& L1,
+                                  const Array<std::string>& L2,
+                                  hash_map<Int, Int>& P);
    
 /// Computes the connected sum of two complexes,
 /// using the first facet of each complex and the
 /// trivial map.
 template <typename Complex_1, typename Complex_2>
-std::list< Set<int> > connected_sum(const Complex_1& C1,
-                                    const Complex_2& C2)
+std::list<Set<Int>> connected_sum(const Complex_1& C1,
+                                  const Complex_2& C2)
 {
-   map P;
+   hash_map<Int, Int> P;
    Array<std::string> L;
-      
-   return connected_sum(C1,C2,0,0,L,L,P);
+   return connected_sum(C1, C2, 0, 0, L, L, P);
 }
 
 } }
 
 #include "polymake/topaz/connected_sum.tcc"
 
-#endif // POLYMAKE_TOPAZ_CONNECTED_SUM_H
 
 // Local Variables:
 // mode:C++
